Index: include/asterisk/format_cap.h
===================================================================
--- include/asterisk/format_cap.h	(revision 422850)
+++ include/asterisk/format_cap.h	(working copy)
@@ -321,4 +321,13 @@
  */
 const char *ast_format_cap_get_names(struct ast_format_cap *cap, struct ast_str **buf);
 
+/*!
+ * \brief Determine if a format cap has no formats in it.
+ *
+ * \param cap The format cap to check for emptiness
+ * \retval 1 The format cap has zero formats or only ast_format_none
+ * \retval 0 The format cap has at least one format
+ */
+int ast_format_cap_empty(struct ast_format_cap *cap);
+
 #endif /* _AST_FORMAT_CAP_H */
Index: main/channel.c
===================================================================
--- main/channel.c	(revision 422850)
+++ main/channel.c	(working copy)
@@ -5327,6 +5327,11 @@
 	ast_assert(rawformat != NULL);
 
 	cap_native = ast_channel_nativeformats(chan);
+	if (ast_format_cap_empty(cap_native)) {
+		ast_log(LOG_ERROR, "Unable to set format because channel %s supports no formats\n",
+				ast_channel_name(chan));
+		return -1;
+	}
 
 	/* Find a translation path from the native format to one of the desired formats */
 	if (!direction) {
Index: main/translate.c
===================================================================
--- main/translate.c	(revision 422850)
+++ main/translate.c	(working copy)
@@ -1276,6 +1276,11 @@
 	int i;
 	int j;
 
+	if (ast_format_cap_empty(dst_cap) || ast_format_cap_empty(src_cap)) {
+		ast_log(LOG_ERROR, "Cannot determine best translation path since one capability supports no formats\n");
+		return -1;
+	}
+
 	if (!(joint_cap = ast_format_cap_alloc(AST_FORMAT_CAP_FLAG_DEFAULT))) {
 		return -1;
 	}
Index: main/format_cap.c
===================================================================
--- main/format_cap.c	(revision 422850)
+++ main/format_cap.c	(working copy)
@@ -700,3 +700,18 @@
 
 	return ast_str_buffer(*buf);
 }
+
+int ast_format_cap_empty(struct ast_format_cap *cap)
+{
+	int count = ast_format_cap_count(cap);
+
+	if (count > 1) {
+		return 0;
+	}
+
+	if (count == 0 || AST_VECTOR_GET(&cap->preference_order, 0)->format == ast_format_none) {
+		return 1;
+	}
+
+	return 0;
+}
